;;; packages.el --- dired-phundrak layer packages file for Spacemacs.
;;
;; Copyright (c) 2012-2018 Sylvain Benner & Contributors
;;
;; Author: Lucien Cartier-Tilet <phundrak@phundrak.fr>
;; URL: https://github.com/syl20bnr/spacemacs
;;
;; This file is not part of GNU Emacs.
;;
;;; License: GPLv3

(global-set-key (kbd "<s-f1>") (lambda () (interactive) (dired "~/")))

(defconst dired-phundrak-packages '(dired
                                    diredfl
                                    dired-git-info
                                    dired-x
                                    image-dired+
                                    org-download)
  "The list of Lisp packages required by the dired-phundrak layer.")

(defun dired-phundrak/post-init-dired ()
  (use-package dired
    :defer t
    :bind (:map dired-mode-map
                ("(" . dired-hide-details-mode))))

(defun dired-phundrak/init-diredfl ()
  "Initializes diredfl and ensures it is enabled globally"
  (use-package diredfl
    :ensure t
    :defer t
    :config
    (diredfl-global-mode 1)))

(defun dired-phundrak/post-init-dired-x ()
  "Initializes dired-x and adds keybindings for its exposed functionalities."
  (use-package dired-x
    :defer t
    :bind (:map dired-mode-map
                ("f" . phundrak//open-marked-files)
                ("F" . xah//open-in-external-app)
                ("s" . xah//dired-sort)
                ("-" . xah//dired-rename-space-to-hyphen)
                ("_" . xah//dired-rename-space-to-underscore))))

(defun dired-phundrak/init-image-dired+ ()
  "Initializes image-dired+ and adds keybindings for its exposed functionalities."
  (use-package image-dired+
    :defer t
    :init ()))

(defun dired-phundrak/post-init-org-download ()
  "Initializes org-download and adds keybindings for its exposed functionalities."
  (use-package org-download
    :defer t
    :init ()))

(defun dired-phundrak/init-dired-git-info ()
  "Initializes dired-git-info package and add keybinding"
  (use-package dired-git-info
    :ensure t
    :bind (:map dired-mode-map
                (")" . dired-git-info-mode))))

;;; packages.el ends here
